@@ -159,7 +159,13 @@ class Window(QWidget):
 
         # Other Slider
         self.bs_lbl = QLabel(self)
-        self.bs_lbl.setText('Bull Shit:')
+
+        print("jah test")
+        bsVar = "bleh"
+        with open("infile.txt", "rb") as file:
+            bsVar = file.read()
+
+        self.bs_lbl.setText(bsVar)
         self.bs_lbl.move(10, 350)
         self.bs_val = QLabel(self)
         self.bs_val.move(165, 350)
@@ -238,9 +244,7 @@ def main_func():
     app.setPalette(window.dark_mode())  # turn on dark mode
     window.show()
     app.exec()
-    print("jah test")
-    with open("infile.txt", "rb") as file:
-        print(file.read())
+
 
 
 if __name__ == '__main__':
